"""
HMTAI PORT REWRITE - by @NMWIN_D (twitter) & NickSaltFoxu ( comeback, guys )
Used original port made by NickSaltFoxu
HMTAI is an Anime / Hentai (NSFW) Image API which simplifies how you fetch random images from the official REST API!\n
"""
from hmtai.hmfull import hmfull

class CategoryNotFound(Exception):
    def __init__(self, categoryn):
        self.categoryn = categoryn
        self.message = f"I don't found '{categoryn}' in list of categories. Please, check docs for right names."
        super().__init__(self.message)

class SourceNotFound(Exception):
    def __init__(self, source):
        self.source = source
        self.message = f"I don't found {source} in list of categories. Please, check docs for right names."
        super().__init__(self.message)

class NoSourceEntered(Exception):
    def __init__(self):
        self.message = f"Source name is empty."
        super().__init__(self.message)

class NoCategoryEntered(Exception):
    def __init__(self):
        self.message = f"Category name is empty."
        super().__init__(self.message)

def get(source = None, category = None):
    if source == None:
        raise NoSourceEntered
    if category == None:
        raise NoCategoryEntered
    if source == "hmtai":
        try:
            res = hmfull.hmtai(category)
            if res == 0:
                raise CategoryNotFound(category)
            else:
                return res
        except Exception as e:
            print(f"ERROR! Contact NickSaltFox#7273 (in discord) with this information!\nDetails: \n  Source: {source}\n Exception: {e}")
    elif source == "nekobot":
        try:
            res = hmfull.nekobot(category)
            if res == 0:
                raise CategoryNotFound(category)
            else:
                return res
        except Exception as e:
            print(f"ERROR! Contact NickSaltFox#7273 (in discord) with this information!\nDetails: \n  Source: {source}\n Exception: {e}")
    elif source == "nekos":
        try:
            res = hmfull.nekos(category)
            if res == 0:
                raise CategoryNotFound(category)
            else:
                return res
        except Exception as e:
            print(f"ERROR! Contact NickSaltFox#7273 (in discord) with this information!\nDetails: \n  Source: {source}\n Exception: {e}")
    elif source == "freaker":
        try:
            res = hmfull.freaker(category)
            if res == 0:
                raise CategoryNotFound(category)
            else:
                return res
        except Exception as e:
            print(f"ERROR! Contact NickSaltFox#7273 (in discord) with this information!\nDetails: \n  Source: {source}\n Exception: {e}")
    elif source == "nekolove":
        try:
            res = hmfull.nekolove(category)
            if res == 0:
                raise CategoryNotFound(category)
            else:
                return res
        except Exception as e:
            print(f"ERROR! Contact NickSaltFox#7273 (in discord) with this information!\nDetails: \n  Source: {source}\n Exception: {e}")

def useHM(version = None, category = None):
    return get("hmtai",f"{category}")



import requests as r
import json

class hmfull:
    def hmtai(category):
        res = r.get(f"https://hmtai.hatsunia.cfd/v2/{category}")
        if "message" in res.json():
            return 0
        else:
            return res.json()["url"]

    def nekos(category):
        blacklist = ['https://cdn.nekos.life/blowjob/blowjob31.jpg', 'https://cdn.nekos.life/blowjob/blowjob32.jpg', 'https://cdn.nekos.life/lewdkemo/lewd_neko_v2_132.jpg', 'https://cdn.nekos.life/Random_hentai_gif/Random_hentai_gifNB_1039.gif']
        res = r.get(url=f"https://nekos.life/api/v2/img/{category}")
        res = json.loads(res.text)
        if "msg" in res:
            return 0
        if res["url"] in blacklist:
            return hmfull.nekos(category)
        return res["url"]

    def nekobot(category):
        blacklist = ['https://i0.nekobot.xyz/0/2/9/1b50d3f619f1bafdf114a530a2570.jpg', 'https://cdn.nekobot.xyz/9/3/9/448bb2ff69b3457a82f32ecd31c06.jpg', 'https://i0.nekobot.xyz/4/9/3/3b6ccf0c081db887fbe38038af996.jpg', 'https://i0.nekobot.xyz/8/6/9/ee21a6ac7d06aabf0b71691e6dfb5.jpg', 'https://cdn.nekobot.xyz/b/4/d/c1fdf4234fbfba326fb282de9ef8c.jpg', 'https://cdn.nekobot.xyz/b/4/d/c1fdf4234fbfba326fb282de9ef8c.jpg']
        res = r.get(f"https://nekobot.xyz/api/image?type={category}")
        if not res.status_code == 200:
            return print('This endpoint don\'t work, or you got a Rate Limit')
        if res.json()["success"] == "false":
            return 0
        if res.json()["message"] in blacklist:
            return hmfull.nekobot(category)
        return res.json()["message"]

    def freaker(category):
        return print('Freaker is not supported for now.')

    def nekolove(category):
        res = r.get(f"https://neko-love.xyz/api/v1/{category}")
        if "message" in res.json():
            return 0
        else:
            return res.json()["url"]



from setuptools import setup, find_packages
from os.path import join, dirname
# read the contents of your README file

setup(
    name='hmtai',
    version='3.2.31',
    license='WTFPL',
    author="NickSaltFoxu",
    author_email='thnyawec@gmail.com',
    packages=['hmtai'],
    url='https://github.com/BlueBerrySans365/HMtai-PY',
    keywords= ["anime", "hentai", "nsfw", "sfw", "images", "gifs", "wallpaper", "discord", "ahegao", "ass", "neko", "yuri", "panties", "thighs", "ero", "kawaii", "cute", "waifu", "hmtai", "zettaiRyouiki", "18+", "REST", "API", "Mikun"],
    long_description=open('README.md', encoding='UTF8').read(),
    long_description_content_type="text/markdown",
    install_requires=[
          'requests',
      ],
)
